# Phinity

A self-improvement SDK for language models.

## Installation

```bash
pip install -e .
```

## Usage

```python
from phinity import LLMGenerator
from phinity.utils.config import Config

# Setup OpenAI
Config.setup_openai()  # Or provide key: Config.setup_openai("your-api-key")

# Create generator
generator = LLMGenerator()

# Generate pairs
instructions = ["Write a haiku about programming"]
pairs = generator.generate_pairs(instructions=instructions)
```
```

Now let's create and activate a virtual environment:

```bash:create_project.sh
# Create project structure
mkdir -p phinity/phinity/{core,generators,evaluators,utils}
mkdir -p phinity/examples
touch phinity/README.md
touch phinity/setup.py
touch phinity/requirements.txt
touch phinity/phinity/__init__.py
touch phinity/phinity/core/__init__.py
touch phinity/phinity/generators/__init__.py
touch phinity/phinity/evaluators/__init__.py
touch phinity/phinity/utils/__init__.py
touch phinity/.env.template
touch phinity/.gitignore

# Create and activate virtual environment
cd phinity
python -m venv venv
source venv/bin/activate  # On Windows, use: venv\Scripts\activate

# Install package in development mode
pip install -e .
```

Now you should be able to:

1. Create the virtual environment and install the package:
```bash
cd phinity
python -m venv venv
source venv/bin/activate  # On Windows, use: venv\Scripts\activate
pip install -e .
```

2. Copy the template and add your API key:
```bash
cp .env.template .env
# Edit .env and add your API key
```

3. Run the test:
```bash
python examples/openai_test.py
```

Would you like me to make any adjustments to these files or add any additional setup steps?